==> FreeUSP-1.01.tgz: trcgp/usp/src/cmd/xsd/helpCB.c <==
/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include "xdisplayP.h"
#include "prototyping.h"
/* #include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <X11/Intrinsic.h>
#include <Xm/Form.h>
#include "XmCreateVa.h"
#include "prototyping.h"
*/


void helpCB(Widget w, XtPointer client_data , XtPointer call_data)
{
  Widget form, scrolledText;
  Widget button;
  FILE *in;
  int length;
  char buf_text[4000];
  char file[1024];
  char *filename=(char *)client_data, *s;

  /* DWN change XSD_DIR to XSD_HELP_DIR  10/19/97 */

  if( (s=getenv("XSD_HELP_DIR")) == NULL ) {
    error_message("XSD_HELP_DIR environment variable not set. Unable to read help file." );
    return;
  }

  strcpy(file,s);
/* DWN 10/19/97
  strcat(file,"help/");
*/
  strcat(file,filename);

  in=fopen(file,"r");
  if (in==NULL) {
    error_message("Error opening help file.");
    fprintf(stderr, "Error opening help file '%s'\n", file );
    return;
  }

  length=fread(buf_text,sizeof(char),4000,in);
  buf_text[length] = '\0';
  
  fclose(in);

  form=XmCreateFormDialogVa(w,"helpForm",
		XmNmarginHeight,10,
		XmNmarginWidth,10,
		XmNdeleteResponse,XmDO_NOTHING,
		XmNdialogTitle,XMstr("Help Dialog"),
		XtNmanageChild,False,
		XmNhelpCallback,
			CBl( helpCB, "help.help" ),
		NULL);

  button = XmCreatePushButtonVa(form,"Cancel",
      XmNbottomAttachment,XmATTACH_FORM,
      XmNleftAttachment,XmATTACH_FORM,
      XmNactivateCallback,
			         CBl( destroyCB, form),
			      NULL);
  
  scrolledText = XmCreateScrolledTextVa(form,"text",
			      XmNbottomAttachment,XmATTACH_WIDGET,
			      XmNbottomWidget,button,
			      XmNtopAttachment,XmATTACH_FORM,
			      XmNleftAttachment,XmATTACH_FORM,
			      XmNrightAttachment,XmATTACH_FORM,
			      XmNvalue,buf_text,
			      XmNrows,15,
			      XmNcolumns,80,
			      XmNwordWrap,True,
			      XmNeditable,False,
			      XmNeditMode,XmMULTI_LINE_EDIT,
			      XmNscrollHorizontal,False,
			      NULL);

  XtManageChild(form);
}

==> FreeUSP-1.01-5.tgz: trcgp/usp/src/cmd/xsd/helpCB.c <==
/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include "xdisplayP.h"
#include "prototyping.h"
/* #include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <X11/Intrinsic.h>
#include <Xm/Form.h>
#include "XmCreateVa.h"
#include "prototyping.h"
*/


void helpCB(Widget w, XtPointer client_data , XtPointer call_data)
{
  Widget form;
  Widget button;
  FILE *in;
  int length;
  char buf_text[4000];
  char file[1024];
  char *filename=(char *)client_data, *s;

  if( (s=getenv("XSD_HELP_DIR")) == NULL ) {
    error_message("XSD_HELP_DIR environment variable not set. Unable to read help file." );
    return;
  }

  strcpy(file,s);
  strcat(file,filename);

  in=fopen(file,"r");
  if (in==NULL) {
    error_message("Error opening help file.");
    fprintf(stderr, "Error opening help file '%s'\n", file );
    return;
  }

  length=fread(buf_text,sizeof(char),4000,in);
  buf_text[length] = '\0';
  
  fclose(in);

  form=XmCreateFormDialogVa(w,"helpForm",
			    XmNmarginHeight,10,
			    XmNmarginWidth,10,
			    XmNdeleteResponse,XmDO_NOTHING,
			    XmNdialogTitle,XMstr("Help Dialog"),
			    XtNmanageChild,False,
			    XmNhelpCallback,
			    CBl( helpCB, "help.help" ),
			    NULL);

  button = XmCreatePushButtonVa(form,"Cancel",
				XmNbottomAttachment,XmATTACH_FORM,
				XmNleftAttachment,XmATTACH_FORM,
				XmNactivateCallback,
				CBl( destroyCB, form),
				NULL);
  
  XmCreateScrolledTextVa(form,"text",
			 XmNbottomAttachment,XmATTACH_WIDGET,
			 XmNbottomWidget,button,
			 XmNtopAttachment,XmATTACH_FORM,
			 XmNleftAttachment,XmATTACH_FORM,
			 XmNrightAttachment,XmATTACH_FORM,
			 XmNvalue,buf_text,
			 XmNrows,15,
			 XmNcolumns,80,
			 XmNwordWrap,True,
			 XmNeditable,False,
			 XmNeditMode,XmMULTI_LINE_EDIT,
			 XmNscrollHorizontal,False,
			 NULL);

  XtManageChild(form);
}
